@@ -28,7 +28,7 @@ class Search(object):
                                "什么",
                                "作用",
                                "知道",
-                               "啊？",
+                               "吗？",
                                "什么",
                                "认识",
                                "What",
@@ -37,6 +37,7 @@ class Search(object):
                                "how",
                                "Who",
                                "Why",
+                               "的作品",
                                "why",
                                "Where",
                                "了解",
@@ -44,8 +45,15 @@ class Search(object):
                                "How to",
                                "how to",
                                "解释",
+                               "怎样的",
+                               "新闻",
+                               "电影",
+                               "2022",
+                               "2023",
                                "请教",
                                "介绍",
+                               "怎样",
+                               "若何", "奈何", "何如",
                                "如何",
                                ]
 
@@ -151,9 +159,9 @@ class Search(object):
     async def check(self, params: PluginConfig) -> bool:
         prompt = params.text
         if len(prompt) < 80:
-            if (prompt.startswith("介绍") or prompt.startswith("查询") or prompt.startswith("你知道")
-                or "2022年" in prompt or "2023年" in prompt) \
-                    or (4 < len(prompt) < 20 and PromptTool.isStrIn(prompt=prompt, keywords=self._help_keywords)):
+            if (prompt.startswith(("介绍", "查询", "你知道", "你了解"))) \
+                    or (10 < len(prompt) < 22 and "?" in prompt or "？" in prompt) \
+                    or (6 < len(prompt) < 26 and PromptTool.isStrIn(prompt=prompt, keywords=self._help_keywords)):
                 return True
         return False
 
@@ -182,14 +190,14 @@ class Search(object):
         # GET
         _returner = []
         _list = await self.get_resource(self._text)
-        _list = _list[:10]
+        _list = _list[:20]
         _returner = NlP.nlp_filter_list(prompt=self._text, material=_list)
         logger.trace(_returner)
         info_cache[self._text] = _returner
         _pre = 0
         info = []
         for i in _returner:
-            if _pre > 220:
+            if _pre > 200:
                 break
             info.append(i)
             _pre += len(gpt_tokenizer.encode(i))
